@@ -10,16 +10,14 @@ from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PrivateKey
 
-from eth_utils import (
-    remove_0x_prefix,
-    to_bytes,
-    to_hex
-)
 
 from mnemonic import Mnemonic
 
 from convex_api.utils import (
+    remove_0x_prefix,
     to_address,
+    to_bytes,
+    to_hex,
     to_public_key_checksum
 )
 
@@ -317,7 +315,7 @@ class Account:
 
 
         """
-        return remove_0x_prefix(self.public_key)
+        return remove_0x_prefix(self.public_key_checksum)
 
     @property
     def public_key_checksum(self):
